@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.6.0-6
+# Application Name - Health Check V0.6.1-0
 #Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -26,9 +26,10 @@
 print "** Start Imports **"
 print "** Importing qtcore & gui **"
 from PyQt4 import QtCore, QtGui
+print "** Importing ui.touchstub - accuracy tool **"
+from ui.touchstub import aMainWindow
 print "** Importing sys **"
 import sys
-
 # To allow os.popen ('<<Terminal command>>').read() commands
 print "** Importing os **"
 import os
@@ -37,7 +38,6 @@ print "** Importing subprocess **"
 import subprocess
 print "** Importing dbus.glib **"
 import dbus.glib
-
 # GPS ones
 print "** Importing Start location**"
 import location
@@ -48,7 +48,6 @@ print "** Importing Cellinfo **"
 import gn_cellinfo
 print "** Importing Hildon **"
 import hildon
-#import pygtk
 
 #for phone orientation call
 #import dbus
@@ -69,10 +68,108 @@ print "** Finish Imports **"
 # Set a global variable - used to send the GPS info from a function back onto its label in the GUI. I'm sure there is a much better way returning
 # the variable in a function, but this works.... Example: http://www.wellho.net/resources/ex.php4?item=y105/locvar.py
 # Setting it to "location" for now.
-print "** Seting global variable **"
+print "** Seting global variables **"
 var_g_GPS = "No GPS lock"
+bname = "Move R"
 
 
+class HelloWindow(QtGui.QMainWindow):
+
+    def __init__(self, *args):
+        apply(QtGui.QMainWindow.__init__, (self,) + args)
+        print "** Starting Hellowindow Class **"
+        global bname
+        #self.Qt::WA_Maemo5StackedWindow 
+        print "** Set basic color on rectangle **"
+        self.color = QtGui.QColor(0, 0, 0) 
+        print "** Setting window details and loading form**"
+        self.setGeometry(0, 0, 800, 480)
+        self.setWindowTitle('Dead Pixel Test')
+
+
+        self.square = QtGui.QWidget(self)
+        self.square.setGeometry(0, 0, 800, 480)
+        self.square.setStyleSheet("QWidget { background-color: %s }" % self.color.name())
+
+        
+        self.red = QtGui.QPushButton('Red', self)
+        self.red.setCheckable(True)
+        self.red.move(10, 10)
+        self.connect(self.red, QtCore.SIGNAL('clicked()'), self.setRed)
+
+        self.green = QtGui.QPushButton('Green', self)
+        self.green.setCheckable(True)
+        self.green.move(10, 60)
+        self.connect(self.green, QtCore.SIGNAL('clicked()'), self.setGreen)
+
+        self.blue = QtGui.QPushButton('Blue', self)
+        self.blue.setCheckable(True)
+        self.blue.move(10, 110)
+        self.connect(self.blue, QtCore.SIGNAL('clicked()'), self.setBlue)
+
+        self.moveb = QtGui.QPushButton('Move R', self)
+        self.moveb.move(10, 160)
+        self.connect(self.moveb, QtCore.SIGNAL('clicked()'), self.moveB)
+
+        self.exitb = QtGui.QPushButton('Exit', self)
+        self.exitb.move(10, 210)
+        self.connect(self.exitb, QtCore.SIGNAL('clicked()'), self.exitB)
+        print "** Completed Hellowindow Class load **"
+        #QtGui.QApplication.setStyle(QtGui.QStyleFactory.create('cleanlooks'))
+
+    def moveB(self):
+        print "** moving buttons **"
+        global bname
+        if bname == "Move R":
+            bname = "Move L"
+            self.moveb.setText("Move L")
+            self.red.move(600, 10)
+            self.green.move(600, 50)
+            self.blue.move(600, 90)
+            self.moveb.move(600, 130)
+            self.exitb.move(600, 170)
+        else:
+            self.moveb.setText("Move R")
+            bname = "Move R"
+            self.red.move(10, 10)
+            self.green.move(10, 50)
+            self.blue.move(10, 90)
+            self.moveb.move(10, 130)
+            self.exitb.move(10, 170)
+        print "** moved buttons**"
+        
+
+    def exitB(self):
+        print "** Exiting Hellowindow Class - closing window **"
+        self.connect(self.exitb, QtCore.SIGNAL('clicked()'), self.close)
+        #MainWindow.show()
+  
+        
+        
+
+    def setRed(self):
+        if self.red.isChecked():
+            self.color.setRed(255)
+        else: self.color.setRed(0)
+
+        self.square.setStyleSheet("QWidget { background-color: %s }" % self.color.name())
+
+    def setGreen(self):
+        if self.green.isChecked():
+            self.color.setGreen(255)
+        else: self.color.setGreen(0)
+
+        self.square.setStyleSheet("QWidget { background-color: %s }" % self.color.name())
+
+    def setBlue(self):
+        if self.blue.isChecked():
+            self.color.setBlue(255)
+        else: self.color.setBlue(0)
+
+        self.square.setStyleSheet("QWidget { background-color: %s }" % self.color.name())
+
+
+        
 class Ui_MainWindow(object):
     def setupUi(self, MainWindow):
         print "** start SetupUi**"
@@ -92,6 +189,7 @@ class Ui_MainWindow(object):
         # Set the Mainwindow to use this font
         MainWindow.setFont(font)
 
+
         # Not sure - QTDesigner did this bit - assuming it's loading up the form and a widget
         self.centralwidget = QtGui.QWidget(MainWindow)
         self.centralwidget.setObjectName("centralwidget")
@@ -212,14 +310,31 @@ class Ui_MainWindow(object):
 
         # Setup and draw the button
         self.pushButton_reboot = QtGui.QPushButton(self.tab_4)
-        self.pushButton_reboot.setGeometry(QtCore.QRect(10, 280, 391, 71))
+        self.pushButton_reboot.setGeometry(QtCore.QRect(10, 280, 391, 51))
         self.pushButton_reboot.setObjectName("pushButton_reboot")
         self.pushButton_reboot.setText("System Reboot")
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
         QtCore.QObject.connect(self.pushButton_reboot, QtCore.SIGNAL('clicked()'), self.reboot_sys)
 
+        self.color_test = QtGui.QPushButton(self.tab_4)
+        self.color_test.setGeometry(QtCore.QRect(400, 190, 391, 51))
+        self.color_test.setObjectName("color_test")
+        self.color_test.setText("Dead Pixel Test")
+        # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
+        QtCore.QObject.connect(self.color_test, QtCore.SIGNAL('clicked()'), self.show_new_window)
+
+        self.xyscreen = QtGui.QPushButton(self.tab_4)
+        self.xyscreen.setGeometry(QtCore.QRect(10, 190, 391, 51))
+        self.xyscreen.setObjectName("xyscreen")
+        self.xyscreen.setText("Accuracy Test")
+        # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
+        QtCore.QObject.connect(self.xyscreen, QtCore.SIGNAL('clicked()'), self.show_new_window2)
+
+        
+        
+
         self.vibra_led = QtGui.QComboBox(self.tab_4)
-        self.vibra_led.setGeometry(QtCore.QRect(400, 200, 391, 71))
+        self.vibra_led.setGeometry(QtCore.QRect(400, 130, 391, 51))
         self.vibra_led.setObjectName("vibra_led")
         self.vibra_led.addItem("PatternIncomingCall")
         self.vibra_led.addItem("PatternIncomingMessage")
@@ -229,14 +344,14 @@ class Ui_MainWindow(object):
         
         
         self.pushButton_von = QtGui.QPushButton(self.tab_4)
-        self.pushButton_von.setGeometry(QtCore.QRect(10, 200, 391, 71))
+        self.pushButton_von.setGeometry(QtCore.QRect(10, 130, 391, 51))
         self.pushButton_von.setObjectName("pushButton_von")
         self.pushButton_von.setText("Test Vibrate")
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
         QtCore.QObject.connect(self.pushButton_von, QtCore.SIGNAL('clicked()'), self.vibrateon)
 
         self.combo_led = QtGui.QComboBox(self.tab_4)
-        self.combo_led.setGeometry(QtCore.QRect(400, 120, 391, 71))
+        self.combo_led.setGeometry(QtCore.QRect(400, 70, 391, 51))
         self.combo_led.setObjectName("combo_led")
         self.combo_led.addItem("PatternError")
         #self.combo_led.addItem("PatternDeviceOn")
@@ -257,14 +372,14 @@ class Ui_MainWindow(object):
         
 
         self.pushButton_led = QtGui.QPushButton(self.tab_4)
-        self.pushButton_led.setGeometry(QtCore.QRect(10, 120, 391, 71))
+        self.pushButton_led.setGeometry(QtCore.QRect(10, 70, 391, 51))
         self.pushButton_led.setObjectName("pushButton_led")
-        self.pushButton_led.setText("Test LED's")
+        self.pushButton_led.setText("Test LEDs")
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
         QtCore.QObject.connect(self.pushButton_led, QtCore.SIGNAL('clicked()'), self.updateLED)
 
         self.sound_lst = QtGui.QComboBox(self.tab_4)
-        self.sound_lst.setGeometry(QtCore.QRect(400, 40, 391, 71))
+        self.sound_lst.setGeometry(QtCore.QRect(400, 10, 391, 51))
         self.sound_lst.setObjectName("sound_lst")
         for f in os.listdir("/usr/share/sounds/"):
             #print f[-3:]
@@ -274,7 +389,7 @@ class Ui_MainWindow(object):
 
 
         self.pushButton_snd1 = QtGui.QPushButton(self.tab_4)
-        self.pushButton_snd1.setGeometry(QtCore.QRect(10, 40, 391, 71))
+        self.pushButton_snd1.setGeometry(QtCore.QRect(10, 10, 391, 51))
         self.pushButton_snd1.setObjectName("pushButton_snd1")
         self.pushButton_snd1.setText("Test Sound")
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
@@ -291,7 +406,7 @@ class Ui_MainWindow(object):
         # box of some sort
         self.textBrowser = QtGui.QTextBrowser(self.tab_5)
         self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-        self.textBrowser.setText (" Health Check V 0.6.0-6 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
+        self.textBrowser.setText (" Health Check V 0.6.1-0 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457 \n\n Thanks to: Mikec(Accuracy test) & Lcuk(Everything!)\n And to all the testers.")
         # Make the font small!!!
         font = QtGui.QFont()
         font.setPointSize(20)
@@ -319,6 +434,21 @@ class Ui_MainWindow(object):
         print "** Show tab1 (0) **"
         self.tabWidget.setCurrentIndex(0)
         QtCore.QMetaObject.connectSlotsByName(MainWindow)
+
+
+
+    def show_new_window(self):
+                   
+        win.show()
+        win.showFullScreen()
+        #appt.connect(appt, SIGNAL("lastWindowClosed()"),appt, SLOT("quit()"))
+        #appt.exec_loop()
+
+    def show_new_window2(self):  
+        aui.show()
+        aui.showFullScreen()
+
+
         
   
 
@@ -778,7 +908,7 @@ class Ui_MainWindow(object):
         
     # This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
     def retranslateUi(self, MainWindow):
-        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.6.0-6", None, QtGui.QApplication.UnicodeUTF8))
+        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.6.1-0", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Camera", None, QtGui.QApplication.UnicodeUTF8))
@@ -789,7 +919,6 @@ class Ui_MainWindow(object):
 # can be found here - http://repository.maemo.org/extras-devel/pool/fremantle/free/source/n/netmon/
     def Cellular(self,MainWindow):
         print " ** Starting Cellular*"
-        print " ** Importing dbus**"
 	#import dbus
 	
 	regstatus = gn_cellinfo.RegStatus()
@@ -911,12 +1040,16 @@ if __name__ == "__main__":
     import sys
     print " ** Starting Main **"
     print " ** app = QtGui App** - Running app = QtGui.QApplication(sys.argv) **"
-
     app = QtGui.QApplication(sys.argv)
 
     #app = QtGui.QApplication(sys.argv)
     print " ** Setting Main Window**"
     MainWindow = QtGui.QMainWindow()
+    #appt=QtGui.QApplication(sys.argv)
+    print "** Setting tool window #1**"
+    win=HelloWindow()
+    print "** Setting tool window #2**"
+    aui = aMainWindow()
     print " ** Declare the UI**"
     ui = Ui_MainWindow()
     print " ** Draw everything and start the main function**"
